@@ -5,7 +5,7 @@ use warnings;
 
 package App::GitGerrit;
 {
-  $App::GitGerrit::VERSION = '0.003';
+  $App::GitGerrit::VERSION = '0.004';
 }
 # ABSTRACT: A container for functions for the git-gerrit program
 
@@ -13,7 +13,6 @@ use Pod::Usage;
 use Getopt::Long qw(:config auto_version auto_help);
 use URI;
 use URI::Escape;
-use Gerrit::REST;
 
 # App::GitGerrit was converted from a script into a module following this:
 # http://elliotlovesperl.com/2009/11/23/how-to-structure-perl-programs/
@@ -256,6 +255,7 @@ sub gerrit {
     state $gerrit;
     unless ($gerrit) {
         my ($username, $password) = get_credentials;
+        require Gerrit::REST;
         $gerrit = Gerrit::REST->new(config('baseurl')->as_string, $username, $password);
         eval { $gerrit->GET("/projects/" . uri_escape_utf8(config('project'))) };
         if ($@) {
@@ -836,7 +836,7 @@ App::GitGerrit - A container for functions for the git-gerrit program
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
